# CreateVolumeRequest

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **String** |  | 
**project** | **String** |  | 
**disk_interface** | **DiskInterface** |  (enum: Block, File) | 
**region** | **String** |  | 
**size_gb** | Option<**serde_json::Value**> |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


